export type SemverPublishLabel = "no version" | "patch" | "minor" | "major";
export declare function isSemverPublishLabel(label: string): label is SemverPublishLabel;
/**
 * NPM publish labels available for the NPM publish action.
 */
export type NpmPublishLabel = SemverPublishLabel;
/**
 * Returns true if the provided label has the conventional format for an NPM publish label,
 * false otherwise.
 *
 * Also acts as a typeguard for Typescript.
 *
 * @param label - The label to test
 */
export declare function isNpmPublishLabel(label: string): label is NpmPublishLabel;
/**
 * Git tag publish labels available for the git tag publish action.
 */
export type GitTagPublishLabel = SemverPublishLabel;
/**
 * Returns true if the provided label has the conventional format for an NPM publish label,
 * false otherwise.
 *
 * Also acts as a typeguard for Typescript.
 *
 * @param label - The label to test
 */
export declare function isGitTagPublishLabel(label: string): label is GitTagPublishLabel;
